# Android Browser Proxy App - User Guide

## Overview

The Android Browser Proxy App allows you to open multiple Android browser instances with residential proxies for debugging TV streams. This guide will help you understand how to use the app effectively.

## Features

- Launch multiple browser instances with different proxy configurations
- Support for various browsers (Chrome, Firefox, Samsung Internet, etc.)
- Free residential proxy integration
- Proxy rotation capabilities
- Country-specific proxy filtering
- Status monitoring and management

## Requirements

- Android 7.0 (API level 24) or higher
- Non-rooted device
- Internet connection
- At least one browser app installed

## Installation

1. Download the APK file from the provided source
2. Enable installation from unknown sources in your device settings
3. Open the APK file and follow the installation prompts
4. Grant the necessary permissions when prompted

## Getting Started

### Main Screen

When you first open the app, you'll see the main screen with the following elements:

- URL input field: Enter the TV stream URL you want to debug
- Browser selection dropdown: Choose which browser to use
- Instance count input: Specify how many browser instances to launch
- Launch button: Start the browsers with proxies
- Rotate Proxies button: Change proxies for active instances
- Stop button: Close all browser instances and stop the service
- Status display: Shows the current status of the app

### Launching Browsers with Proxies

1. Enter the URL of the TV stream you want to debug
2. Select the browser you want to use
3. Enter the number of instances you want to launch (1-10)
4. Tap the "Launch" button
5. The app will start the proxy service, obtain free proxies, and launch the specified number of browser instances

### Rotating Proxies

If you want to change the proxies for active browser instances:

1. Tap the "Rotate Proxies" button
2. The app will obtain new proxies and refresh the browser instances
3. The status display will show how many proxies were successfully rotated

### Stopping the Service

When you're done debugging:

1. Tap the "Stop" button
2. The app will close all browser instances and stop the proxy service
3. The status display will confirm when the service has stopped

## Advanced Usage

### Using Different Browser Types

The app supports multiple browser types. To use different browsers simultaneously:

1. Make sure you have multiple browsers installed on your device
2. The app will automatically detect installed browsers
3. You can launch different browser types with the same proxy or different proxies

### Country-Specific Proxies

For debugging content that requires proxies from specific countries:

1. The app includes functionality to filter proxies by country
2. This feature is available through the API but not directly exposed in the UI
3. The free proxy list includes proxies from various countries

### Proxy Rotation Settings

The app includes several proxy rotation strategies:

1. Time-based rotation: Proxies are rotated after a specified time interval
2. Error-based rotation: Proxies are rotated when they fail
3. Manual rotation: You can manually rotate proxies using the "Rotate Proxies" button

## Troubleshooting

### No Browsers Launch

- Check that you have at least one supported browser installed
- Verify that you have an active internet connection
- Ensure you've entered a valid URL

### Proxy Connection Issues

- Free proxies may have limited reliability and performance
- Try rotating proxies if connections are slow or failing
- Check that your device has proper internet connectivity

### App Crashes

- Ensure your Android version is 7.0 or higher
- Check that you've granted all necessary permissions
- Try restarting the app

## Technical Details

### How It Works

The app uses Android's Intent system to launch browser instances with different proxy configurations. For non-rooted devices, it uses system properties to configure proxies for each browser instance.

### Proxy Sources

The app uses free proxy sources which may have limitations:
- Limited bandwidth
- Potential reliability issues
- Varying performance

### Privacy and Security

- The app does not collect or store any personal data
- Proxy connections are used only for the browser instances you launch
- All proxy configuration is done locally on your device

## Support

For additional support or to report issues, please contact the developer.

---

This user guide provides a comprehensive overview of the Android Browser Proxy App's features and functionality. For more detailed technical information, please refer to the developer documentation.
